@@ -1,3 +1,4 @@
+from enum import Enum
 from typing import List, Union
 
 import numpy as np
@@ -5,13 +6,22 @@ import numpy as np
 from .curve import to_exceedance_curve
 
 
+class ImpactType(Enum):
+    damage = 1
+    disruption = 2
+
+
 class ImpactDistrib:
     """Impact distributions specific to an asset."""
 
-    __slots__ = ["__event_type", "__impact_bins", "__prob"]
+    __slots__ = ["__event_type", "__impact_bins", "__prob", "impact_type"]
 
     def __init__(
-        self, event_type: type, impact_bins: Union[List[float], np.ndarray], prob: Union[List[float], np.ndarray]
+        self,
+        event_type: type,
+        impact_bins: Union[List[float], np.ndarray],
+        prob: Union[List[float], np.ndarray],
+        impact_type: ImpactType = ImpactType.damage,
     ):
         """Create a new asset event distribution.
         Args:
@@ -21,6 +31,7 @@ class ImpactDistrib:
         """
         self.__event_type = event_type
         self.__impact_bins = np.array(impact_bins)
+        self.impact_type = impact_type
         self.__prob = np.array(prob)
 
     def impact_bins_explicit(self):
@@ -32,6 +43,10 @@ class ImpactDistrib:
     def to_exceedance_curve(self):
         return to_exceedance_curve(self.__impact_bins, self.__prob)
 
+    @property
+    def event_type(self) -> type:
+        return self.__event_type
+
     @property
     def impact_bins(self) -> np.ndarray:
         return self.__impact_bins
